==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_image.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_image.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("IMALAN_1", "Enable image display");
define("IMALAN_2", "Display images, this will apply sitewide (comments, chatbox etc) to images posted using the [img] bbcode");
define("IMALAN_3", "Resize method");
define("IMALAN_4", "Method used to resize images, either GD1/2 library, or ImageMagick");
define("IMALAN_5", "Path to ImageMagick (if selected)");
define("IMALAN_6", "Full path to ImageMagick Convert utility");
define("IMALAN_7", "Image Settings");
define("IMALAN_8", "Update Image Settings");
define("IMALAN_9", "Image settings updated");
define("IMALAN_10", "Image display class");
define("IMALAN_11", "Restrict users who can view images (if enabled above)");
define("IMALAN_12", "Disabled image method");
define("IMALAN_13", "What to do with images if image display is disabled");
define("IMALAN_14", "Show image URL");
define("IMALAN_15", "Show nothing");
define("IMALAN_16", "Show uploaded avatars");
define("IMALAN_17", "Click here");
define("IMALAN_18", "Uploaded images");
define("IMALAN_19", "Show 'disabled' message");

define("IMALAN_21", "Used by");
define("IMALAN_22", "Image not in use");
define("IMALAN_23", "Avatar");
define("IMALAN_24", "Photograph");
define("IMALAN_25", "Click here to delete all unused images");
define("IMALAN_26", "image(s) deleted");

define("IMALAN_28", "deleted");
define("IMALAN_29", "No images");
define("IMALAN_30", "Everyone (public)");
define("IMALAN_31", "Guests only");
define("IMALAN_32", "Members only");
define("IMALAN_33", "Admin only");
define("IMALAN_34", "Enable Sleight");
define("IMALAN_35", "Fixes transparent PNG-24's with alpha transparency in IE 5 / 6 (Applies Sitewide)");

define("IMALAN_36", "Validate avatar size and access");
define("IMALAN_37", "Avatar Validation");
define("IMALAN_38", "Maximum allowable width");
define("IMALAN_39", "Maximum allowable height");
define("IMALAN_40", "Too wide");
define("IMALAN_41", "Too high");
define("IMALAN_42", "Not found");
define("IMALAN_43", "Delete uploaded avatar");
define("IMALAN_44", "Delete external reference");
define("IMALAN_45", "Not found");
define("IMALAN_46", "Too large");
define("IMALAN_47", "Total uploaded avatars");
define("IMALAN_48", "Total external avatars");
define("IMALAN_49", "Users with avatars");
define("IMALAN_50", "Total");
define("IMALAN_51", "Avatar for ");

define("IMALAN_52", "Path to ImageMagick appears to be incorrect");
define("IMALAN_53", "Path to ImageMagick appears to be correct, but convert file may not be valid");
define("IMALAN_54", "GD version installed:");
define('IMALAN_55', 'Not installed');

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_image.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_image.php $
|     $Revision: 11678 $
|     $Id: lan_image.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("IMALAN_1", "Enable image display");
define("IMALAN_2", "Display images, this will apply sitewide (comments, chatbox etc) to images posted using the [img] bbcode");
define("IMALAN_3", "Resize method");
define("IMALAN_4", "Method used to resize images, either GD1/2 library, or ImageMagick");
define("IMALAN_5", "Path to ImageMagick (if selected)");
define("IMALAN_6", "Full path to ImageMagick Convert utility");
define("IMALAN_7", "Image Settings");
define("IMALAN_8", "Update Image Settings");
define("IMALAN_9", "Image settings updated");
define("IMALAN_10", "Image display class");
define("IMALAN_11", "Restrict users who can view images (if enabled above)");
define("IMALAN_12", "Disabled image method");
define("IMALAN_13", "What to do with images if image display is disabled");
define("IMALAN_14", "Show image URL");
define("IMALAN_15", "Show nothing");
define("IMALAN_16", "Show uploaded avatars");
define("IMALAN_17", "Click here");
define("IMALAN_18", "Uploaded images");
define("IMALAN_19", "Show 'disabled' message");

define("IMALAN_21", "Used by");
define("IMALAN_22", "Image not in use");
define("IMALAN_23", "Avatar");
define("IMALAN_24", "Photograph");
define("IMALAN_25", "Click here to delete all unused images");
define("IMALAN_26", "image(s) deleted");

define("IMALAN_28", "deleted");
define("IMALAN_29", "No images");
define("IMALAN_30", "Everyone (public)");
define("IMALAN_31", "Guests only");
define("IMALAN_32", "Members only");
define("IMALAN_33", "Admin only");
define("IMALAN_34", "Enable Sleight");
define("IMALAN_35", "Fixes transparent PNG-24's with alpha transparency in IE 5 / 6 (Applies Sitewide)");

define("IMALAN_36", "Validate avatar size and access");
define("IMALAN_37", "Avatar Validation");
define("IMALAN_38", "Maximum allowable width");
define("IMALAN_39", "Maximum allowable height");
define("IMALAN_40", "Too wide");
define("IMALAN_41", "Too high");
define("IMALAN_42", "Not found");
define("IMALAN_43", "Delete uploaded avatar");
define("IMALAN_44", "Delete external reference");
define("IMALAN_45", "Not found");
define("IMALAN_46", "Too large");
define("IMALAN_47", "Total uploaded avatars");
define("IMALAN_48", "Total external avatars");
define("IMALAN_49", "Users with avatars");
define("IMALAN_50", "Total");
define("IMALAN_51", "Avatar for ");

define("IMALAN_52", "Path to ImageMagick appears to be incorrect");
define("IMALAN_53", "Path to ImageMagick appears to be correct, but convert file may not be valid");
define("IMALAN_54", "GD version installed:");
define('IMALAN_55', 'Not installed');

?>
